<?php
/**
 * This file represents an example of the code that themes would use to register
 * the required plugins.
 *
 * It is expected that theme authors would copy and paste this code into their
 * functions.php file, and amend to suit.
 *
 * @see http://tgmpluginactivation.com/configuration/ for detailed documentation.
 *
 * @package    TGM-Plugin-Activation
 * @subpackage Javo
 * @version    2.6.1 for parent theme Javobp for publication on ThemeForest
 * @author     Thomas Griffin, Gary Jones, Juliette Reinders Folmer
 * @copyright  Copyright (c) 2011, Thomas Griffin
 * @license    http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
 * @link       https://github.com/TGMPA/TGM-Plugin-Activation
 */



add_action( 'tgmpa_register', 'jvbpd_register_required_plugins' );
function jvbpd_register_required_plugins() {

	$config = array(
		'id'           => 'jvbpd',                 // Unique ID for hashing notices for multiple instances of TGMPA.
		'default_path' => '',                      // Default absolute path to bundled plugins.
		'menu'         => 'tgmpa-install-plugins', // Menu slug.
		'has_notices'  => true,                    // Show admin notices or not.
		'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
		'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
		'is_automatic' => false,                   // Automatically activate plugins after installation or not.
		'message'      => '',                      // Message to output right before the plugins table.
	);

	$coreName = 'Javo Core';
	tgmpa(
		apply_filters( 'jvbpd_tgmpa_plugins', Array(
			Array(
				'name' => $coreName,
				'slug' => sanitize_title( $coreName ),
				'version' => '2.0.1.78',
				'required' => true,
				'force_activation' => false,
				'force_deactivation' => false,
				'external_url' => '',
				'source' => get_template_directory() . '/inc/Plugins/javo-core.zip',
				'image_url' => JVBPD_IMG_DIR . '/icon/jv-default-setting-plugin-javo-core.png',
			),
			Array(
				'name' => 'BuddyPress',
				'slug' => 'buddypress',
				'required' => true,
				'force_activation' => false,
				'force_deactivation' => false,
				'image_url' => esc_url_raw( JVBPD_IMG_DIR . '/icon/jv-default-setting-plugin-buddypress.png' ),
			),
			Array(
				'name' => 'Contact Form 7',
				'slug' => 'contact-form-7',
				'required' => true,
				'force_activation' => false,
				'force_deactivation' => false,
				'image_url' => 'https://ps.w.org/contact-form-7/assets/icon-256x256.png',
			),
			Array(
				'name' => 'Elementor',
				'slug' => 'elementor',
				'required' => true,
				'force_activation' => false,
				'force_deactivation' => false,
				'image_url' => JVBPD_IMG_DIR . '/icon/jv-default-setting-plugin-elementor.png',
			),
			Array(
				'name' => 'Easy Forms for Mailchimp',
				'slug' => 'yikes-inc-easy-mailchimp-extender',
				'required' => true,
				'force_activation' => false,
				'force_deactivation' => false,
				'image_url' => 'https://ps.w.org/yikes-inc-easy-mailchimp-extender/assets/icon-256x256.png',
			),
			Array(
				'name' => 'Post Views Counter',
				'slug' => 'post-views-counter',
				'required' => false,
				'force_activation' => false,
				'force_deactivation' => false,
				'image_url' => 'https://ps.w.org/post-views-counter/assets/icon-256x256.png',
			),
			Array(
				'name' => 'Lava Ajax Search',
				'slug' => 'lava-ajax-search',
				'required' => false,
				'force_activation' => false,
				'force_deactivation' => false,
				'source' => get_template_directory() . '/inc/Plugins/lava-ajax-search.zip',
				'image_url' => JVBPD_IMG_DIR . '/icon/jv-default-setting-plugin-ajax-search.png',
			),
			Array(
				'name' => 'Lava Bookings',
				'slug' => 'lava-bookings',
				'version' => '1.0.0.18',
				'required' => true,
				'force_activation' => false,
				'force_deactivation' => false,
				'external_url' => '',
				'source' => get_template_directory() . '/inc/Plugins/lava-bookings.zip',
				'image_url' => '//lava-code.com/directory/wp-content/uploads/sites/16/2016/01/booking.jpg',
			),
			Array(
				'name' => 'Lava Bp Post',
				'slug' => 'lava-bp-post',
				'required' => false,
				'force_activation' => false,
				'force_deactivation' => false,
				'source' => get_template_directory() . '/inc/Plugins/lava-bp-post.zip',
				'image_url' => JVBPD_IMG_DIR . '/icon/jv-default-setting-plugin-bp-post.png',
			),
			Array(
				'name' => 'Lava Directory 3D Viewer',
				'slug' => 'lava-directory-3dViewer',
				'version' => '1.0.3',
				'required' => true,
				'force_activation' => false,
				'force_deactivation' => false,
				'external_url' => '',
				'source' => get_template_directory() . '/inc/Plugins/lava-directory-3dViewer.zip',
				'image_url' => '//lava-code.com/directory/wp-content/uploads/sites/16/2015/10/3d.jpg',
			),
			Array(
				'name' => 'Lava Directory Approve Email Addons',
				'slug' => 'lava-directory-approve-email',
				'version' => '1.0.1',
				'required' => true,
				'force_activation' => false,
				'force_deactivation' => false,
				'external_url' => '',
				'source' => get_template_directory() . '/inc/Plugins/lava-directory-approve-email.zip',
				'image_url' => '//lava-code.com/directory/wp-content/uploads/sites/16/2015/10/email.jpg',
			),
			Array(
				'name' => 'Lava Directory Claim Addons',
				'slug' => 'lava-directory-claim',
				'version' => '1.1.2.11',
				'required' => true,
				'force_activation' => false,
				'force_deactivation' => false,
				'external_url' => '',
				'source' => get_template_directory() . '/inc/Plugins/lava-directory-claim.zip',
				'image_url' => '//lava-code.com/directory/wp-content/uploads/sites/16/2015/10/Claim.jpg',
			),
			Array(
				'name' => 'Lava Directory Manager',
				'slug' => 'lava-directory-manager',
				'required' => true,
				'force_activation' => false,
				'force_deactivation' => false,
				'source' => get_template_directory() . '/inc/Plugins/lava-directory-manager.zip',
				'image_url' => JVBPD_IMG_DIR . '/icon/jv-default-setting-plugin-lava-directory-manager.png',
			),
			Array(
				'name' => 'Lava Directory Manager Pro',
				'slug' => 'lava-directory-manager-pro',
				'version' => '0.0.0.121',
				'required' => true,
				'force_activation' => false,
				'force_deactivation' => false,
				'external_url' => '',
				'source' => get_template_directory() . '/inc/Plugins/lava-directory-manager-pro.zip',
				'image_url' => JVBPD_IMG_DIR . '/icon/jv-default-setting-plugin-lava-directory-manager.png',
			),
			Array(
				'name' => 'Lava Directory Payment',
				'slug' => 'lava-directory-payment',
				'version' => '1.0.8.13',
				'required' => true,
				'force_activation' => false,
				'force_deactivation' => false,
				'external_url' => '',
				'source' => get_template_directory() . '/inc/Plugins/lava-directory-payment.zip',
				'image_url' => 'https://lava-code.com/directory/wp-content/uploads/sites/16/2015/10/payment.jpg',
			),
			Array(
				'name' => 'Lava Directory Video',
				'slug' => 'lava-directory-video',
				'version' => '1.0.3.1',
				'required' => true,
				'force_activation' => false,
				'force_deactivation' => false,
				'external_url' => '',
				'source' => get_template_directory() . '/inc/Plugins/lava-directory-video.zip',
				'image_url' => 'https://lava-code.com/directory/wp-content/uploads/sites/16/2016/01/video.jpg',
			),
			Array(
				'name' => 'Lava directory woocommerce vendor manager',
				'slug' => 'lava-directory-wc-vendor-manager',
				'version' => '1.0.2.4',
				'required' => true,
				'force_activation' => false,
				'force_deactivation' => false,
				'external_url' => '',
				'source' => get_template_directory() . '/inc/Plugins/lava-directory-wc-vendor-manager.zip',
				'image_url' => 'https://lava-code.com/directory/wp-content/uploads/sites/16/2016/01/wc_vendor.jpg',
			),
			Array(
				'name' => 'Lava Dynamic Accordion',
				'slug' => 'lava-dynamic-accordion',
				'version' => '0.0.0.8',
				'required' => true,
				'force_activation' => false,
				'force_deactivation' => false,
				'external_url' => '',
				'source' => get_template_directory() . '/inc/Plugins/lava-dynamic-accordion.zip',
				'image_url' => JVBPD_IMG_DIR . '/icon/jv-default-setting-plugin-lava-directory-manager.png',
			),
			Array(
				'name' => 'Lava Dynamic Compare',
				'slug' => 'lava-dynamic-compare',
				'version' => '0.0.0.4',
				'required' => true,
				'force_activation' => false,
				'force_deactivation' => false,
				'external_url' => '',
				'source' => get_template_directory() . '/inc/Plugins/lava-dynamic-compare.zip',
				'image_url' => JVBPD_IMG_DIR . '/icon/jv-default-setting-plugin-lava-directory-manager.png',
			),
			Array(
				'name' => 'Lava FaQ',
				'slug' => 'lava-faq',
				'version' => '1.0.1.4',
				'required' => true,
				'force_activation' => false,
				'force_deactivation' => false,
				'external_url' => '',
				'source' => get_template_directory() . '/inc/Plugins/lava-faq.zip',
				'image_url' => 'https://lava-code.com/directory/wp-content/uploads/sites/16/2017/12/lava-code-faq.gif',
			),
			Array(
				'name' => 'Lava Favorite',
				'slug' => 'lava-directory-favorite',
				'version' => '1.0.3.6',
				'required' => true,
				'force_activation' => false,
				'force_deactivation' => false,
				'external_url' => '',
				'source' => get_template_directory() . '/inc/Plugins/lava-directory-favorite.zip',
				'image_url' => 'https://lava-code.com/directory/wp-content/uploads/sites/16/2015/10/Favorite.jpg',
			),
			Array(
				'name' => 'Lava More Taxonomies',
				'slug' => 'lava-more-taxonomies',
				'version' => '1.0.3.8',
				'required' => true,
				'force_activation' => false,
				'force_deactivation' => false,
				'external_url' => '',
				'source' => get_template_directory() . '/inc/Plugins/lava-more-taxonomies.zip',
				'image_url' => 'https://lava-code.com/directory/wp-content/uploads/sites/16/2017/12/lava-code-more-taxonomies.gif',
			),
			Array(
				'name' => 'Lava Mortgage Calculator',
				'slug' => 'lava-mortgage-calculator',
				'version' => '0.0.0.3',
				'required' => true,
				'force_activation' => false,
				'force_deactivation' => false,
				'external_url' => '',
				'source' => get_template_directory() . '/inc/Plugins/lava-mortgage-calculator.zip',
				'image_url' => JVBPD_IMG_DIR . '/icon/jv-default-setting-plugin-lava-directory-manager.png',
			),
			Array(
				'name' => 'Lava NearBy Places',
				'slug' => 'lava-nearby-places',
				'version' => '0.0.0.11',
				'required' => true,
				'force_activation' => false,
				'force_deactivation' => false,
				'external_url' => '',
				'source' => get_template_directory() . '/inc/Plugins/lava-nearby-places.zip',
				'image_url' => JVBPD_IMG_DIR . '/icon/jv-default-setting-plugin-lava-directory-manager.png',
			),
			Array(
				'name' => 'Lava Open Hours',
				'slug' => 'lava-open-hours',
				'version' => '1.0.2.17',
				'required' => true,
				'force_activation' => false,
				'force_deactivation' => false,
				'external_url' => '',
				'source' => get_template_directory() . '/inc/Plugins/lava-open-hours.zip',
				'image_url' => 'https://lava-code.com/directory/wp-content/uploads/sites/16/2017/12/lava-code-open-hours.gif',
			),
			Array(
				'name' => 'Lava post review',
				'slug' => 'lava-post-review',
				'version' => '1.0.2.79',
				'required' => true,
				'force_activation' => false,
				'force_deactivation' => false,
				'external_url' => '',
				'source' => get_template_directory() . '/inc/Plugins/lava-post-review.zip',
				'image_url' => 'https://lava-code.com/directory/wp-content/uploads/sites/16/2015/10/lava-review.png',
			),
			Array(
				'name' => 'Lava View Counter Connector',
				'slug' => 'lava-view-counter-connector',
				'version' => '1.0.0',
				'required' => true,
				'force_activation' => false,
				'force_deactivation' => false,
				'external_url' => '',
				'source' => get_template_directory() . '/inc/Plugins/lava-view-counter-connector.zip',
				'image_url' => 'https://lava-code.com/directory/wp-content/uploads/sites/16/2018/11/lava-code-view-counter.gif',
			),
			Array(
				'name' => 'Lava WC PageBuilder',
				'slug' => 'lava-wc-pagebuilder',
				'version' => '1.0.0.137',
				'required' => true,
				'force_activation' => false,
				'force_deactivation' => false,
				'external_url' => '',
				'source' => get_template_directory() . '/inc/Plugins/lava-wc-pagebuilder.zip',
				'image_url' => 'https://lava-code.com/directory/wp-content/uploads/sites/16/2020/05/Lava-WC-PageBuilder-300x300.png',
			),
			Array(
				'name' => 'Woocommerce',
				'slug' => 'woocommerce',
				'required' => true,
				'force_activation' => false,
				'force_deactivation' => false,
				'image_url' => 'https://ps.w.org/woocommerce/assets/icon-256x256.png',
			),
			Array(
				'name'      => 'One Click Demo Import',
				'slug'      => 'one-click-demo-import',
				'required'  => false,
				'image_url' => 'https://ps.w.org/one-click-demo-import/assets/icon-256x256.png',
			),
		) ),
		apply_filters( 'jvbpd_tgmpa_config', $config )
	);
}
