<?php
namespace Javo\Api\Reports;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.

}
abstract class Base {
	protected $_properties;

	abstract public function get_title();
	abstract public function get_fields();

	public function is_enabled() {
		return true;
	}

	final public function get_report( $format = '' ) {
		$result = [];

		$format = ( empty( $format ) ) ? '' : $format . '_';

		foreach ( $this->get_fields() as $field_name => $field_label ) {
			$method = 'get_' . $format . $field_name;

			if ( ! method_exists( $this, $method ) ) {
				$method = 'get_' . $field_name;
				//fallback:
				if ( ! method_exists( $this, $method ) ) {
					return new \WP_Error( sprintf( "Getter method for the field '%s' wasn't found in %s.", $field_name, get_called_class() ) );
				}
			}

			$reporter_field = [
				'name' => $field_name,
				'label' => $field_label,
			];

			$reporter_field = array_merge( $reporter_field, $this->$method() );
			$result[ $field_name ] = $reporter_field;
		}

		return $result;
	}

	public static function get_properties_keys() {
		return [
			'name',
			'format',
			'fields',
		];
	}
	public function __construct( $properties = null ) {}
}
