<?php
/**
 * Helpers methods
 * List all your static functions you wish to use globally on your theme
 *
 * @package JavoThemes
 */


if( ! function_exists( 'jvbpd_start_wizard' ) ) {
	function jvbpd_start_wizard() {
		if( get_option( 'jvbpd_wizard_setup_visit' ) == 'yes' ) {
			return;
		}

		wp_safe_redirect( esc_url( add_query_arg( Array( 'page' => 'jvbpd-core' ), admin_url( 'themes.php' ) ) ) );
		update_option( 'jvbpd_wizard_setup_visit', 'yes' );
		die;
	}
}

if( ! function_exists( 'jvbpd_remove_theme_options' ) ) {
	function jvbpd_remove_theme_options() {
		delete_option( 'jvbpd_wizard_setup_visit' );
	}
}

if ( ! function_exists( 'jvbpd_var_dump' ) ) {
	/**
	 * Var_dump and die method
	 *
	 * @return void
	 */
	function jvbpd_var_dump() {
		echo '<pre>';
		array_map( function( $x ) {
			var_dump( $x );
		}, func_get_args() );
		echo '</pre>';
		die;
	}
}

if ( ! function_exists( 'jvbpd_starts_with' ) ) {
	/**
	 * Determine if a given string starts with a given substring.
	 *
	 * @param  string  $haystack
	 * @param  string|array  $needles
	 * @return bool
	 */
	function jvbpd_starts_with($haystack, $needles)
	{
		foreach ((array) $needles as $needle) {
			if ($needle != '' && substr($haystack, 0, strlen($needle)) === (string) $needle) {
				return true;
			}
		}
		return false;
	}
}
if (! function_exists('jvbpd_get_mix_path')) {
	/**
	 * Get the path to a versioned Mix file.
	 *
	 * @param  string  $path
	 * @param  string  $manifestDirectory
	 * @return \Illuminate\Support\HtmlString
	 *
	 * @throws \Exception
	 */
	function jvbpd_get_mix_path($path, $manifestDirectory = '')
	{
		if (! $manifestDirectory) {
			$manifestDirectory = "assets/dist/";
		}
		static $manifest;
		if (! jvbpd_starts_with($path, '/')) {
			$path = "/{$path}";
		}
		if ($manifestDirectory && ! jvbpd_starts_with($manifestDirectory, '/')) {
			$manifestDirectory = "/{$manifestDirectory}";
		}
		$rootDir = dirname(__FILE__, 2);
		if (file_exists($rootDir . '/' . $manifestDirectory.'/hot')) {
			return getenv('WP_SITEURL') . ":8080" . $path;
		}
		if (! $manifest) {
			$manifestPath =  $rootDir . $manifestDirectory . 'mix-manifest.json';
			if (! file_exists($manifestPath)) {
				throw new Exception('The Mix manifest does not exist.');
			}
			ob_start();
			include $manifestPath;
			$manifest = json_decode(ob_get_contents(), true);
			ob_end_clean();
		}
		$path = untrailingslashit($manifestDirectory) . $manifest[$path];
		return get_template_directory_uri() . $path;
	}
}